@@ -1,8 +1,7 @@
 """ Loads Carving base tools."""
 
-from .base_carver import BaseCarver, load_carver
 from .binary_carver import BinaryCarver
 from .continuous_carver import ContinuousCarver
 from .multiclass_carver import MulticlassCarver
 
-__all__ = ["BaseCarver", "load_carver", "BinaryCarver", "ContinuousCarver", "MulticlassCarver"]
+__all__ = ["BinaryCarver", "ContinuousCarver", "MulticlassCarver"]
